#define _CRT_SECURE_NO_DEPRECATE

#include "testlib.h"

#include <string>
#include <vector>
#include <list>
#include <map>
#include <set>
#include <deque>
#include <queue>
#include <stack>
#include <bitset>
#include <algorithm>
#include <functional>
#include <numeric>
#include <utility>
#include <sstream>
#include <iostream>
#include <iomanip>
#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>
#include <memory.h>
#include <string.h>
#include <signal.h>

using namespace std;

#define pb push_back
#define pf push_front
#define mp make_pair
#define fi(a, b) for(i=a; i<=b; i++)
#define fj(a, b) for(j=a; j<=b; j++)
#define fo(a, b) for(o=a; o<=b; o++)
#define fdi(a, b) for(i=a; i>=b; i--)
#define fdj(a, b) for(j=a; j>=b; j--)
#define fdo(a, b) for(o=a; o>=b; o--)
#define ZERO(x) memset(x, 0, sizeof(x));
#define COPY(x, y) memcpy(x, y, sizeof(y));
#define SIZE(x) (int)x.size()
#define LEN(x) (int)x.length()

typedef long long int64;

FILE *fin;

#ifdef LOG

FILE *flog, *flog2;

#endif

void finish(int code, const string &s) {
	fprintf(stderr, "%s\n", s.c_str());
	fclose(stderr);
	exit(code);
}

void ok(const string &s) {
	finish(0, s);
}

void wa(const string &s) {
	finish(1, s);
}

void pe(const string &s) {
	finish(2, s);
}

void ql(const string &s) {
	finish(3, s);
}

void ir(const string &s) {
	finish(4, s);
}

void id(const string &s) {
	finish(5, s);
}

#ifdef LOG

void Log(string s) {
	fprintf(flog, "%s\n", s.c_str());
	fflush(flog);
}

#endif

#define MAX 50

#define MAX_QUERIES 2000

int dim;
int n;

double A[MAX][MAX];

double norm[MAX][MAX];
double p[MAX][MAX];

double last[MAX];
double cur[MAX];

double x[MAX];
double y[MAX];

double eps = 1e-3;

double Scal(double a[MAX], double b[MAX]) {
	int i;
	double res;
	res = 0;
	fi(1, dim) {
		res += a[i] * b[i];
	}
	return res;
}

void Projection(double a[MAX], int num, double proj[MAX]) {
	double s;
	double g[MAX];
	double v[MAX];
	int i;
	ZERO(g);
	ZERO(proj);
	ZERO(v);
	
	fi(1, dim) {
		g[i] = p[num][i] - a[i];
	}
		
	s = Scal(g, norm[num]);
	
	fi(1, dim) {
		v[i] = s * norm[num][i];
	}
	fi(1, dim) {
		proj[i] = a[i] + v[i];
	}
}

void Mult(double v[MAX], double res[MAX]) {
	int i, j;
	fi(1, dim) {
		res[i] = 0;
	}
	fj(1, dim) {
		fi(1, dim) {
			res[j] += A[j][i] * v[i];
		}
	}
}

double Dist(double a[MAX], double b[MAX]) {
	int i;
	double Aa[MAX], Ab[MAX];
	double res;
	ZERO(Aa);
	ZERO(Ab);
	Mult(a, Aa);
	Mult(b, Ab);
	res = 0;
	fi(1, dim) {
		res += (Aa[i] - Ab[i]) * (Aa[i] - Ab[i]);
	}
	return sqrt(res);
}

void Reflect(int num) {
	int i;
	double proj[MAX];
	double v[MAX];
	Projection(cur, num, proj);
	ZERO(v);
	fi(1, dim) {
		v[i] = proj[i] - cur[i];
	}
	fi(1, dim) {
		cur[i] += 2 * v[i];
	}
	fi(1, dim) {
		printf("%.9lf%c", cur[i], " \n"[i == dim]);
	}
#ifdef LOG
	fi(1, dim) {
		fprintf(flog, "%.9lf%c", cur[i], " \n"[i == dim]);
		fprintf(flog2, "%.9lf%c", cur[i], " \n"[i == dim]);
	}
	fflush(flog);
	fflush(flog2);
#endif
	fflush(stdout);
}

void Request() {
	printf("%.9lf\n", Dist(last, cur));
#ifdef LOG
	fprintf(flog, "%.9lf\n", Dist(last, cur));
	fprintf(flog2, "%.9lf\n", Dist(last, cur));
	fflush(flog);
	fflush(flog2);
#endif
	COPY(last, cur);
	fflush(stdout);
}

int main() {
	fin = fopen(getenv("JUDGE_TEST_IN"), "r");
	double ans;
	double l;
	char str[100];
	char com[100];
	int q;
	int num;
	int i, j;
#ifdef LOG
	flog = fopen("log.txt", "w");
	flog2 = fopen("log2.txt", "w");
#endif
	fscanf(fin, "%d", &dim);
	n = 2 * dim;

	fj(1, dim) {
		fi(1, dim) {
			fscanf(fin, "%lf", &A[j][i]);
		}
	}

	fj(1, n) {
		fi(1, dim) {
			fscanf(fin, "%lf", &norm[j][i]);
		}
		fi(1, dim) {
			fscanf(fin, "%lf", &p[j][i]);
		}
	}

	fi(1, dim) {
		fscanf(fin, "%lf", &x[i]);
	}

	fi(1, dim) {
		fscanf(fin, "%lf", &y[i]);
	}

	printf("%d\n", dim);

	fj(1, n) {
		fi(1, dim) {
			printf("%.0lf%c", norm[j][i], " \n"[i == dim]);
		}
		fi(1, dim) {
			printf("%.0lf%c", p[j][i], " \n"[i == dim]);
		}
	}

	fi(1, dim) {
		printf("%.0lf%c", x[i], " \n"[i == dim]);
	}

	fi(1, dim) {
		printf("%.0lf%c", y[i], " \n"[i == dim]);
	}

	fflush(stdout);

#ifdef LOG

	fprintf(flog, "%d\n", dim);
	fprintf(flog2, "%d\n", dim);

	fj(1, n) {
		fi(1, dim) {
			fprintf(flog, "%.0lf%c", norm[j][i], " \n"[i == dim]);
			fprintf(flog2, "%.0lf%c", norm[j][i], " \n"[i == dim]);
		}
		fi(1, dim) {
			fprintf(flog, "%.0lf%c", p[j][i], " \n"[i == dim]);
			fprintf(flog2, "%.0lf%c", p[j][i], " \n"[i == dim]);
		}
	}

	fi(1, dim) {
		fprintf(flog, "%.0lf%c", x[i], " \n"[i == dim]);
		fprintf(flog2, "%.0lf%c", x[i], " \n"[i == dim]);
	}

	fi(1, dim) {
		fprintf(flog, "%.0lf%c", y[i], " \n"[i == dim]);
		fprintf(flog2, "%.0lf%c", y[i], " \n"[i == dim]);
	}

	fflush(flog);
	fflush(flog2);

#endif

	fj(1, n) {
		l = 0;
		fi(1, dim) {
			l += norm[j][i] * norm[j][i];
		}
		l = sqrt(l);
		fi(1, dim) {
			norm[j][i] /= l;
		}
	}

	ZERO(last);
	ZERO(cur);

	q = 0;
	while (1) {
		q++;
		switch (scanf("%10s", com)) {
			case 1:
				break;
			case -1:
				id("Unexpected EOF");
				break;
			default:
				pe("Wrong output format");
				break;
		}

#ifdef LOG
		fprintf(flog, "%s ", com);
#endif

		if (strcmp(com, "Reflect") == 0) {
			switch (scanf("%d", &num)) {
				case 1:
					break;
				case -1:
					id("Unexpected EOF");
					break;
				default:
					pe("Wrong output format");
					break;
			}
			if (num < 1 || num > n) {
				pe("Wrong hyperplane number");
			}

#ifdef LOG
		fprintf(flog, "%d\n", num);
		fflush(flog);
#endif

			Reflect(num);
		} else if (strcmp(com, "Request") == 0) {
#ifdef LOG
		fprintf(flog, "\n");
		fflush(flog);
#endif
			Request();
		} else if (strcmp(com, "Answer") == 0) {
			switch (scanf("%lf", &ans)) {
				case 1:
					break;
				case -1:
					id("Unexpected EOF");
					break;
				default:
					pe("Wrong output format");
					break;
			}
#ifdef LOG
		fprintf(flog, "%.9lf\n", ans);
		fflush(flog);
#endif
			if (fabs(ans - Dist(x, y)) < eps || fabs(ans - Dist(x, y)) / fabs(ans) < eps) {
				printf("Y\n");
				fflush(stdout);
#ifdef LOG
				fprintf(flog, "Y\n", ans);
				fprintf(flog2, "Y\n", ans);
				fflush(flog);
				fflush(flog2);
#endif
				sprintf(str, "%d queries. Answer: %.9lf", q, Dist(x, y));
				ok(str);
			}
			printf("N\n");
#ifdef LOG
			fprintf(flog, "Wrong. Right answer: %.9lf\n", Dist(x, y));
			fprintf(flog2, "0\n");
			fflush(flog);
			fflush(flog2);
#endif
			fflush(stdout);
		} else {
			//printf("Q\n");
			//fflush(stdout);
			pe("Wrong command");
		}

		if (q >= MAX_QUERIES) {
			//printf("Q\n");
			//fflush(stdout);
#ifdef LOG
			fprintf(flog, "Q\n", ans);
			fprintf(flog2, "Q\n", ans);
			fflush(flog);
			fflush(flog2);
#endif
			ql("Too many queries");
		}
	}

	return 0;
}
