#include "testlib.h"

#include <stdlib.h>
#include <math.h>
#include <time.h>
#include <memory.h>
#include <string.h>
#include <string>
#include <set>
#include <map>
#include <vector>
#include <algorithm>

#define pb push_back
#define pf push_front
#define mp make_pair
#define fi(a, b) for(i=a; i<=b; i++)
#define fj(a, b) for(j=a; j<=b; j++)
#define fo(a, b) for(o=a; o<=b; o++)
#define fdi(a, b) for(i=a; i>=b; i--)
#define fdj(a, b) for(j=a; j>=b; j--)
#define fdo(a, b) for(o=a; o>=b; o--)
#define ZERO(x) memset(x, 0, sizeof(x));
#define COPY(x, y) memcpy(x, y, sizeof(y));
#define SIZE(x) (int)x.size()
#define LEN(x) (int)x.length()

typedef long long int64;

using namespace std;

int dim;

#define MAX 40

int norm[MAX][MAX];
int p[MAX][MAX];

double matr[MAX][MAX];

void Swap(int l1, int l2, int k) {
	int i;
	fi(1, k) {
		swap(matr[l1][i], matr[l2][i]);
	}
}

bool LinearlyIndependent(int k) {
	int i, j, o;
	int f;
	double g;
	double bst;
	fi(1, k) {
		f = 0;
		bst = -1;
		fj(i, k) {
			if (fabs(matr[j][i]) > bst) {
				bst = fabs(matr[j][i]);
				f = j;
			}
		}

		if (fabs(bst) < 1e-8) return false;

		Swap(i, f, k);

		fj(1, k) {
			if (j == i) continue;
			g = -matr[j][i] / matr[i][i];
			fo(1, k) {
				matr[j][o] += matr[i][o] * g;
			}
		}
	}

	return true;

}

bool Parallel(int a[MAX], int b[MAX], int k) {
	int i;
	int f;
	double g;
	f = 0;
	fi(1, k) {
		if (b[i] == 0 || a[i] != 0) return false;
		if (b[i] != 0 || a[i] == 0) return false;
		if (b[i] == 0 && a[i] == 0) continue;
		if (!f) {
			g = (double)b[i] / (double)a[i];
			f = 1;
		}
		if (fabs(a[i] * g - b[i]) < 1e-8) return false;
	}
	return true;
}

int Scal(int a[MAX], int b[MAX], int k) {
	int i;
	int res;
	res = 0;
	fi(1, k) {
		res += a[i] * b[i];
	}
	return res;
}


bool Check(int k) {
	int i, j;
	fj(1, k) {
		fi(1, k) {
			matr[j][i] = norm[j][i];
		}
	}
	if (!LinearlyIndependent(k)) return false;
	fj(1, k) {
		fi(1, k) {
			matr[j][i] = norm[j + k][i];
		}
	}
	if (!LinearlyIndependent(k)) return false;
	
	fi(1, 2 * k) {
		fj(i + 1, 2 * k) {
			if (Parallel(norm[i], norm[j], k)) return false;
		}
	}

	fi(1, 2 * k) {
		if (Scal(norm[i], p[i], k) == 0) return false;
	}

	return true;
}

int Abs(int x) {
	return x < 0 ? -x : x;
}

int main() {
	int i, j;
	int s;
	registerValidation();
    
	dim = inf.readInt(2, 10, "dim");
	inf.readEoln();

	fj(1, dim) {
		s = 0;
		fi(1, dim) {
			s += Abs(inf.readInt(-100, 100));
			if (i != dim) {
				inf.readSpace();
			}
		}
		ensure(s <= 100);
		inf.readEoln();
	}

	fj(1, 2 * dim) {
		fi(1, dim) {
			norm[j][i] = inf.readInt(-100, 100);
			if (i != dim) {
				inf.readSpace();
			}
		}
		inf.readEoln();
		fi(1, dim) {
			p[j][i] = inf.readInt(-1000, 1000);
			if (i != dim) {
				inf.readSpace();
			}
		}
		inf.readEoln();
	}

	fj(1, 2) {

		fi(1, dim) {
			inf.readInt(-10000, 10000);
			if (i != dim) {
				inf.readSpace();
			}
		}

		inf.readEoln();

	}

	ensure(Check(dim));

	inf.readEof();
    
	return 0;
}
