#define _CRT_SECURE_NO_DEPRECATE

#include "testlib.h"

#include <string>
#include <vector>
#include <list>
#include <map>
#include <set>
#include <deque>
#include <queue>
#include <stack>
#include <bitset>
#include <algorithm>
#include <functional>
#include <numeric>
#include <utility>
#include <sstream>
#include <iostream>
#include <iomanip>
#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>
#include <memory.h>
#include <string.h>
#include <signal.h>

using namespace std;

#define pb push_back
#define pf push_front
#define mp make_pair
#define fi(a, b) for(i=a; i<=b; i++)
#define fj(a, b) for(j=a; j<=b; j++)
#define fo(a, b) for(o=a; o<=b; o++)
#define fdi(a, b) for(i=a; i>=b; i--)
#define fdj(a, b) for(j=a; j>=b; j--)
#define fdo(a, b) for(o=a; o>=b; o--)
#define ZERO(x) memset(x, 0, sizeof(x));
#define COPY(x, y) memcpy(x, y, sizeof(y));
#define SIZE(x) (int)x.size()
#define LEN(x) (int)x.length()

typedef long long int64;

FILE *fin;

#ifdef LOG

FILE *flog;

#endif

void finish(int code, const string &s) {
	fprintf(stderr, "%s\n", s.c_str());
	fclose(stderr);
	exit(code);
}

void ok(const string &s) {
	finish(0, s);
}

void wa(const string &s) {
	finish(1, s);
}

void pe(const string &s) {
	finish(2, s);
}

void ql(const string &s) {
	finish(3, s);
}

void ir(const string &s) {
	finish(4, s);
}

void id(const string &s) {
	finish(5, s);
}

#ifdef LOG

void Log(string s) {
	fprintf(flog, "%s\n", s.c_str());
	fflush(flog);
}

#endif

#define X1 -1050
#define X2 -1000
#define LENGTH 1000
#define VELOCITY 100
#define DT 0.5
#define G 9.80665
#define RADIUS 0.1

double phi, psi;

double vx, vy, vz;
double x, y, z;
double t;
double eps = 1e-9;

double sqr(double x) {
	return x * x;
}

double Dist(double x1, double y1, double z1, double x2, double y2, double z2) {
	return sqrt(sqr(x2 - x1) + sqr(y2 - y1) + sqr(z2 - z1));
}

double Square(double a, double b, double c) {
	double p;
	p = (a + b + c) / 2;
	if (p * (p - a) * (p - b) * (p - c) < 0) return 0;
	return sqrt(p * (p - a) * (p - b) * (p - c));
}

int q;

int main() {
	fin = fopen(getenv("JUDGE_TEST_IN"), "r");
	double ty, tz;
	double d;
	char str[100];
#ifdef LOG
	flog = fopen("log.txt", "w");
#endif

	fscanf(fin, "%lf %lf", &phi, &psi);

	vx = cos(phi) * cos(psi);
	vy = sin(phi) * cos(psi);
	vz = sin(psi);

	vx *= VELOCITY;
	vy *= VELOCITY;
	vz *= VELOCITY;
	
	q = 0;
	t = 0;

	while (1) {
		t += DT;
		x = vx * t;
		y = vy * t;
		z = vz * t - G * sqr(t) / 2;
		if (z <= eps) {
			printf("Quit\n");
			fflush(stdout);
#ifdef LOG
			fprintf(flog, "Quit\n", d);
			fflush(flog);
#endif
			wa("The ball has fallen");
		}
		q++;
		switch (scanf("%lf %lf", &ty, &tz)) {
			case 2:
				break;
			case -1:
				id("Unexpected EOF");
				break;
			default:
				pe("Wrong output format");
				break;
		}
		if (fabs(ty) > LENGTH || tz < -eps || tz > LENGTH) {
			//printf("Quit\n");
			//fflush(stdout);
#ifdef LOG
			fprintf(flog, "Quit\n", d);
			fflush(flog);
#endif
			pe("Coordinates are out of range");
		}

		d = 2 * Square(Dist(x, y, z, X1, 0, 0), Dist(x, y, z, X2, ty, tz), Dist(X1, 0, 0, X2, ty, tz)) / (Dist(X1, 0, 0, X2, ty, tz) + 1e-10);

		if (d <= RADIUS + eps) {
			printf("Quit\n");
			fflush(stdout);
#ifdef LOG
			fprintf(flog, "Quit\n", d);
			fflush(flog);
#endif
			sprintf(str, "The ball was hit at (%.5lf, %.5lf, %.5lf) after %d shot(s)", x, y, z, q);
			ok(str);
		}

		printf("Miss %.9lf\n", d);
		fflush(stdout);
#ifdef LOG
		fprintf(flog, "Miss %.9lf\n", d);
		fflush(flog);
#endif
	}

	return 0;
}
