#define _CRT_SECURE_NO_DEPRECATE

#include <string>
#include <vector>
#include <list>
#include <map>
#include <set>
#include <deque>
#include <queue>
#include <stack>
#include <bitset>
#include <algorithm>
#include <functional>
#include <numeric>
#include <utility>
#include <sstream>
#include <iostream>
#include <iomanip>
#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>
#include <memory.h>
#include <string.h>

using namespace std;

#define pb push_back
#define pf push_front
#define mp make_pair
#define fi(a, b) for(i=a; i<=b; i++)
#define fj(a, b) for(j=a; j<=b; j++)
#define fo(a, b) for(o=a; o<=b; o++)
#define fdi(a, b) for(i=a; i>=b; i--)
#define fdj(a, b) for(j=a; j>=b; j--)
#define fdo(a, b) for(o=a; o>=b; o--)
#define ZERO(x) memset(x, 0, sizeof(x));
#define COPY(x, y) memcpy(x, y, sizeof(y));
#define SIZE(x) (int)x.size()
#define LEN(x) (int)x.length()

typedef long long int64;

#define X1 -1050
#define X2 -1000
#define LENGTH 100
#define VELOCITY 100
#define DT 0.5
#define G 9.80665
#define RADIUS 1

double sqr(double x) {
	return x * x;
}

double Dist(double x1, double y1, double z1, double x2, double y2, double z2) {
	return sqrt(sqr(x2 - x1) + sqr(y2 - y1) + sqr(z2 - z1));
}

struct Seg {
	double l, r;
	Seg(double a, double b) {
		l = a;
		r = b;
	}
	Seg () {
	}
};

struct Rec {
	double ty, tz;
	double d;
	double t;
};

double pi = acos(-1.);

double eps = 1e-3;

vector <Seg> vs;
vector <Seg> vs2;

vector <Rec> v;

void Shoot(double phi, double psi, double t) {
	char str[100];
	Rec r;
	double d;
	double x, y, z;
	double vx, vy, vz;
	double dx, dy, dz;
	double ty, tz;	

	vx = cos(phi) * cos(psi);
	vy = sin(phi) * cos(psi);
	vz = sin(psi);

	vx *= VELOCITY;
	vy *= VELOCITY;
	vz *= VELOCITY;

	x = vx * t;
	y = vy * t;
	z = vz * t - G * sqr(t) / 2;

	dx = (x - X1);
	dy = y;
	dz = z;

	ty = ((X2 - X1) / dx) * dy;
	tz = ((X2 - X1) / dx) * dz;

	printf("%.9lf %.9lf\n", ty, tz);
	fflush(stdout);

	scanf("%s", str);

	if (strcmp(str, "Quit") == 0) {
		exit(0);
	}

	scanf("%lf", &d);

	r.ty = ty;
	r.tz = tz;
	r.d = d;
	r.t = t;

	v.pb(r);

}

double Square(double a, double b, double c) {
	double p;
	p = (a + b + c) / 2;
	return sqrt(p * (p - a) * (p - b) * (p - c));
}

double DistToLine(double phi, double psi, Rec g) {
	double x, y, z;
	double vx, vy, vz;

	vx = cos(phi) * cos(psi);
	vy = sin(phi) * cos(psi);
	vz = sin(psi);

	vx *= VELOCITY;
	vy *= VELOCITY;
	vz *= VELOCITY;

	x = vx * g.t;
	y = vy * g.t;
	z = vz * g.t - G * sqr(g.t) / 2;

	return 2 * Square(Dist(x, y, z, X1, 0, 0), Dist(x, y, z, X2, g.ty, g.tz), Dist(X1, 0, 0, X2, g.ty, g.tz)) / Dist(X1, 0, 0, X2, g.ty, g.tz);
}

pair <double, double> FindPsi(double phi, int q = 3) {
	int i, j, o;
	double l, r, h1, h2;
	double res;
	double ress;
	double s;
	double s1;
	double s2;

	res = -1;
	ress = 10e9;

	fo(0, q - 1) {

		l = pi / 4 + o * (pi / 4) / q;
		r = pi / 4 + (o + 1) * (pi / 4) / q;

		s = 0;

		fi(0, SIZE(v) - 1) {
			s += fabs(DistToLine(phi, l, v[i]) - v[i].d);
		}

		if (s < ress) {
			ress = s;
			res = l;
		}

		fj(1, 20) {
			h1 = l + (r - l) / 3;
			h2 = r - (r - l) / 3;

			s1 = 0;
			s2 = 0;

			fi(0, SIZE(v) - 1) {
				s1 += fabs(DistToLine(phi, h1, v[i]) - v[i].d);
				s2 += fabs(DistToLine(phi, h2, v[i]) - v[i].d);
			}		

			if (s1 > s2) {
				l = h1;
			} else {
				r = h2;
			}
		}

		s = 0;

		fi(0, SIZE(v) - 1) {
			s += fabs(DistToLine(phi, (l + r) / 2, v[i]) - v[i].d);
		}

		if (s < ress) {
			ress = s;
			res = (l + r) / 2;
		}

	}

	return mp(ress, res);
}

bool Check(Seg s) {
	int i;
	double l, r, h1, h2;
	double res;
	
	l = s.l;
	r = s.r;

	res = min(FindPsi(l).first, FindPsi(r).first);

	fi(1, 30) {
		h1 = l + (r - l) / 3;
		h2 = r - (r - l) / 3;
		if (FindPsi(h1).first > FindPsi(h2).first) {
			l = h1;
		} else {
			r = h2;
		}
	}

	res = min(res, FindPsi((l + r) / 2).first);

	if (res > eps) return false;

	return true;
}

int main() {
	int i, j;
	int num;
	double phi;
	double t;
	Seg s;

	s.l = 0;
	s.r = 2 * pi;

	vs.pb(s);

	t = 0;

	t += DT;
	Shoot(0, pi / 2, t);

	t += DT;
	Shoot(0, pi / 4, t);

	t += DT;
	Shoot(pi / 2, pi / 4, t);

	t += DT;
	Shoot(pi, pi / 4, t);

	t += DT;
	Shoot(3 * pi / 2, pi / 4, t);	

	t += DT;
	Shoot(0, pi / 2, t);
	fj(1, 5) {
		while (SIZE(vs) < 12) {
			vs2.clear();
			fi(0, SIZE(vs) - 1) {
				vs2.pb(Seg(vs[i].l, (vs[i].l + vs[i].r) / 2));
				vs2.pb(Seg((vs[i].l + vs[i].r) / 2, vs[i].r));
			}
			vs = vs2;
		}
		while (1) {
			vs2.clear();
			fi(0, SIZE(vs) - 1) {

				if (Check(vs[i])) {
					vs2.pb(vs[i]);
				}

			}
			if (SIZE(vs2) > 0) break;
			eps *= 2;
		}
		
		vs = vs2;		
	
	}
	
	while (1) {
		t += DT;
		num = rand() % SIZE(vs);			
		phi = (vs[num].r + vs[num].l) / 2;
		Shoot(phi, FindPsi(phi, 10).second, t);
	}

	return 0;
}
